TanStack Query-style declarative server-state management for Relm applications.
Provides:
update handlers for queries (::update, ::fetch), mutations (::mutate), and invalidation (::invalidate)TanStack Query-style declarative server-state management for Relm applications. Provides: - Vector query key normalization and matching (exact, prefix/hierarchical) - Optional helpers to extract URLs and query parameters from vector keys or Reitit routes - Explicit and helper-driven cache invalidation (exact single key, hierarchical prefix, predicate, all) - Declarative Relm `update` handlers for queries (`::update`, `::fetch`), mutations (`::mutate`), and invalidation (`::invalidate`) - Pure context cache state reducers and Hiccup view query helpers - Automatic stale detection, configurable retries with exponential backoff, and optimistic mutations
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |